Available on
docsrs only.Expand description
About the generated framework crates
The objc2 project provides (mostly) autogenerated interfaces to Apple’s
Objective-C frameworks like AppKit, Foundation, Metal, WebKit, and so on.
The bindings currently contain some documentation from the headers, but you should view Apple’s canonical developer documentation for detailed information about each API (there are some plans for importing that documentation, but it’s difficult).
These crates uses objc2 to declare the external interface to the
Objective-C classes and protocols. It is highly recommended that you read
the documentation here for details on how the Objective-C interop works.
They also use block2::Block in the public API, check out the documentation
for the block2 crate for how to call such methods using a closure.
Modules
- cargo_
features - Cargo features and long compile-times in framework crates
- changelog
- Framework crate changelog
- deref
- Use of
Deref - list
- List of framework crates